# PageInfo

The information about the current page fetch in a pagination query. Use this to fetch the next or previous page. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**page_on** | [**PageOn**](PageOn.md) |  | 
**page_at_key** | [**PageAtKey**](PageAtKey.md) |  | 
**previous_key** | [**PageAtKey**](PageAtKey.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


